@@ -1,5 +1,7 @@
 from shutil import which
 import PyInquirer
+import requests
+import sys
 
 from fds.domain.commands import Commands
 from fds.logger import Logger
@@ -8,7 +10,7 @@ from fds.services.fds_service import FdsService
 from fds.services.git_service import GitService
 from fds.services.pretty_print import PrettyPrint
 from fds.utils import execute_command
-
+from .__init__ import __version__
 
 class Run(object):
     def __init__(self, arguments: dict):
@@ -44,6 +46,26 @@ class Run(object):
             self.printer.error("git executable is not found, please install git from https://git-scm.com/downloads")
             ret_code |= 2
 
+        r = requests.get("https://pypi.python.org/pypi/fastds/json")
+        data = r.json()
+        latest_version = data["info"]["version"]
+        if latest_version != __version__:
+            questions = [
+                {
+                    'type': 'confirm',
+                    'message': f"You are using fds version {__version__}, however version {latest_version} is available. Should we upgrade using `pip install fastds --upgrade`",
+                    'name': 'install',
+                    'default': 'True',
+            },
+            ]
+            answers = PyInquirer.prompt(questions)
+            if answers["install"]:
+                print("\nUpgrading package. Please re-enter the command once upgrade has been completed.\n")
+                execute_command(["pip install fastds --upgrade"], shell=True, capture_output=False)
+                sys.exit()
+            else:
+                ret_code = 0
+
         return ret_code
 
     def execute(self):
@@ -66,6 +88,10 @@ class Run(object):
             # Run add command stuff
             self.service.add(arguments["add_command"])
             return 0
+        elif arguments["command"] == Commands.CLONE.value:
+            # Run clone command stuff
+            self.service.clone(arguments["url"], arguments["folder_name"][0], arguments["dvc_remote"])
+            return 0
         elif arguments["command"] == Commands.COMMIT.value:
             if len(arguments.get("message", [])) == 1:
                 message = arguments["message"][0]
