@@ -1,12 +1,12 @@
 import os
-from typing import Any
+from typing import Any, Optional
 
-from fds.services.base_service import BaseService
 from fds.services.pretty_print import PrettyPrint
-from fds.utils import execute_command, convert_bytes_to_string, does_file_exist, check_git_ignore
+from fds.utils import execute_command, convert_bytes_to_string, does_file_exist, check_git_ignore, \
+    get_git_repo_name_from_url
 
 
-class GitService(BaseService):
+class GitService(object):
     """
     Git Service responsible for all the git commands of fds
     """
@@ -55,3 +55,9 @@ class GitService(BaseService):
                     raise Exception("No git branch found to push to")
                 push_cmd.append(curr_branch)
         execute_command(push_cmd, capture_output=False)
+
+    def clone(self, url: str, folder_name: Optional[str]) -> Any:
+        if folder_name is None or folder_name == "":
+            folder_name = get_git_repo_name_from_url(url)
+        execute_command(["git", "clone", url, folder_name], capture_output=False)
+        return folder_name
