@@ -1,3 +1,4 @@
+import os
 from unittest.mock import patch
 
 from fds.services.dvc_service import DvcChoices
@@ -98,3 +99,37 @@ class TestDvc(IntegrationTestCase):
         self.dvc_service.commit(False)
         output = execute_command(["dvc", "dag"], capture_output=True)
         assert "large_file.dvc" in convert_bytes_to_string(output.stdout)
+
+    def test_clone(self):
+        self.fds_service.clone(self.get_remote_url_for_test(), None, None)
+        assert does_file_exist(f"{self.repo_path}/hello-world")
+        # Checking dvc pull
+        assert does_file_exist(f"{self.repo_path}/hello-world/data")
+
+    def test_clone_with_remote_name(self):
+        folder_name = self.git_service.clone(self.get_remote_url_for_test(), None)
+        os.chdir(folder_name)
+        self.dvc_service.pull(self.get_remote_url_for_test(), "origin")
+        assert does_file_exist(f"{self.repo_path}/hello-world/data")
+
+    def test_clone_dagshub_url(self):
+        folder_name = self.git_service.clone(self.get_remote_url_for_test(), None)
+        os.chdir(folder_name)
+        self.dvc_service.pull(self.get_remote_url_for_test(), None)
+        assert does_file_exist(f"{self.repo_path}/hello-world/data")
+
+    @patch("fds.services.dvc_service.DVCService._show_choice_of_remotes", return_value="storage")
+    def test_clone_show_remotes_list(self, get_choice):
+        url = "https://github.com/iterative/example-get-started.git"
+        folder_name = self.git_service.clone(url, None)
+        os.chdir(folder_name)
+        self.dvc_service.pull(url, None)
+        assert does_file_exist(f"{self.repo_path}/example-get-started/data/data.xml")
+
+    @patch("fds.services.dvc_service.DVCService._show_choice_of_remotes", return_value="storage")
+    def test_clone_given_remote(self, get_choice):
+        url = "https://github.com/iterative/example-get-started.git"
+        folder_name = self.git_service.clone(url, None)
+        os.chdir(folder_name)
+        self.dvc_service.pull(url, "storage")
+        assert does_file_exist(f"{self.repo_path}/example-get-started/data/data.xml")
