@@ -57,3 +57,32 @@ class TestFds(IntegrationTestCase):
         self.fds_service.commit("Commit 1", False)
         output = execute_command(["git", "log", "--oneline"], capture_output=True)
         assert "Commit 1" in convert_bytes_to_string(output.stdout)
+
+    def test_clone(self):
+        self.fds_service.clone(self.get_remote_url_for_test(), None, None)
+        # Check git clone
+        assert does_file_exist(f"{self.repo_path}/hello-world")
+        # Checking dvc pull
+        assert does_file_exist(f"{self.repo_path}/hello-world/data")
+
+    def test_clone_empty(self):
+        self.fds_service.clone(self.get_remote_url_for_test(), "", None)
+        # Check git clone
+        assert does_file_exist(f"{self.repo_path}/hello-world")
+        # Checking dvc pull
+        assert does_file_exist(f"{self.repo_path}/hello-world/data")
+
+    def test_clone_git_custom_name(self):
+        self.fds_service.clone(self.get_remote_url_for_test(), "test", None)
+        # Check git clone
+        assert does_file_exist(f"{self.repo_path}/test")
+        # Checking dvc pull
+        assert does_file_exist(f"{self.repo_path}/test/data")
+
+    def test_clone_given_remote(self):
+        url = "https://github.com/iterative/example-get-started.git"
+        self.fds_service.clone(url, "start", "storage")
+        # Check git clone
+        assert does_file_exist(f"{self.repo_path}/start")
+        # Checking dvc pull of storage remote
+        assert does_file_exist(f"{self.repo_path}/start/data/data.xml")
